larch.reactive - A reactive programming library for Python
==========================================================

`larch.reactive` is a `reactive programming library
<https://en.wikipedia.org/wiki/Reactive_programming>`_ for Python.
The objectives of `larch.reactive` are:

- To be lean
- To be fast
- To be compatible (it should be possible to add reactive behavior
  to existing classes)
- To provide a consistent programming model
- To be debuggable

Installation
------------

Install `larch.reactive` either from a distribution package or from
`PyPI <https://pypi.org/project/larch-reactive>`_ with:

.. code-block:: bash

   $ pip install larch-reactive

License
-------

`larch.reactive` is released under the BSD license.

Documentation
-------------

For more information, please refer to the full documentation available at:

`larch.reactive Documentation <https://kochelmonster.github.io/larch-reactive/index.html>`_